@@ -82,12 +82,7 @@ void add_slot(SCM slot_data)
   hslot->length = hslot->exposed = 0;
   update_slot_length(hslot);
 
-  if (slot_list)
-    g_list_append(slot_list, hslot);
-  else {
-    slot_list = g_list_alloc();
-    slot_list->data = hslot;
-  }
+  slot_list = g_list_append(slot_list, hslot);
 }
 
 hcard_type new_card(SCM card_data) 
@@ -525,9 +520,10 @@ cscmi_catch_handler (gpointer data,
   cscmi_write_exception_details (error_fd, tag, throw_args);
   close (error_fd);
 
-  exec_str = g_strdup_printf ("bug-buddy --package=gnome-games --package-version=%s --appname=aisleriot --kill=%d --include=%s",
+  exec_str = g_strdup_printf ("bug-buddy --package=gnome-games --package-ver=%s --appname=aisleriot --pid=%d --kill=%d --include=%s",
 			      VERSION,
 			      getpid (),
+			      getpid (),
 			      error_file);
   system (exec_str);
   unlink (error_file);
