@@ -1,5 +1,5 @@
 /* AisleRiot - menu.h
- * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+ * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,8 +23,16 @@
 void random_seed ( void );
 void undo_callback ( void );
 void redo_callback ( void );
-void help_about_callback ( void );
 void create_menus ( void );
-void install_menu_hints ( GnomeApp * );
+void toolbar_hide ( void );
+void undo_set_sensitive (gboolean state);
+void redo_set_sensitive (gboolean state);
+void option_list_set_sensitive (void);
+void help_update_game_name (gchar * name);
+void install_options_menu (gchar *name);
+
+extern GtkUIManager *ui_manager;
+extern GtkWidget *menubar;
+extern GtkWidget *toolbar;
 
 #endif
